Jido.Agent.Directive.StopSensor (Jido v2.3.0)

Copy Markdown View Source

Stop a tagged sensor runtime owned by the current agent runtime.

The sensor is identified by the same tag used by StartSensor. Missing sensors are a no-op. Stopping a sensor does not emit jido.agent.child.exit or jido.agent.sensor.exit; the sensor exit signal is reserved for unexpected runtime exits.

Fields

  • tag - Agent-local tag for the sensor runtime
  • reason - Reason for stopping (default: :normal)

Examples

%StopSensor{tag: :market_data}
%StopSensor{tag: {:poller, "AAPL"}, reason: :reconfigured}

Summary

Functions

Returns the Zoi schema for StopSensor.

Types

t()

@type t() :: %Jido.Agent.Directive.StopSensor{reason: any(), tag: any()}

Functions

schema()

@spec schema() :: Zoi.schema()

Returns the Zoi schema for StopSensor.