Default no-op tracer implementation.
This tracer does nothing and is used when no external tracing backend is configured. All span operations return immediately without side effects.
Default no-op tracer implementation.
This tracer does nothing and is used when no external tracing backend is configured. All span operations return immediately without side effects.