Jido.Plugin.Spec
(Jido v2.2.0)
The normalized representation of a plugin attached to an agent.
Contains all metadata needed to integrate a plugin with an agent, including actions, schema, configuration, and signal patterns.
Summary
Types
@type t() :: %Jido.Plugin.Spec{ actions: [atom()], category: nil | nil | binary(), config: %{optional(atom()) => any()}, config_schema: nil | nil | any(), description: nil | nil | binary(), module: atom(), name: binary(), schema: nil | nil | any(), signal_patterns: [binary()], state_key: atom(), tags: [binary()], vsn: nil | nil | binary() }